==> aionx-1.0.2.tar.gz: aionx-1.0.2/README.md <==
# Machine Learning and Deep Learning for time series forecast

![MIT License](https://img.shields.io/badge/license-MIT-yellow.svg)
![Python](https://img.shields.io/badge/python-3.10%2B-blue)

This repository contains code and resources for Time Series forecast and analysis using Machine Learning and Deep Learning and is available under the MIT license. 

## Features

- Machine Learning and Deep Learning models for time series.
- Easy-to-use examples with [Scikit-Learn](https://scikit-learn.org/stable/), [Keras](https://keras.io/) and eventually [PyTorch](https://pytorch.org/).
- Only four dependencies:
    - [NumPy](https://numpy.org/) : The fundamental package for scientific computing in Python.
    - [Pandas](https://pandas.pydata.org/) : An open-source data analysis and manipulation library.
    - [TensorFlow](https://www.tensorflow.org/) : An open-source deep learning framework.
    - [Scikit-Learn](https://scikit-learn.org/stable/) : An open-source machine learning framework.
 
## Models

- Density Hemisphere Neural Network (DensityHNN):
    - Implements the model proposed by [Paper](linktopaper). DensityHNN is a deep Learning algorithm designed to produce Density forecasts on time-dependent data...

## Getting Started

1. Clone this repository:

    ```bash
    git clone https://github.com/MikGitML/aion.git
    ```

2. Install the required dependencies:

    ```bash
    pip install -r requirements.txt
    ```

3. (TODO) explore the example notebooks in the `examples/` directory to get started.

## Usage

This repository provides a simple and flexible framework for time series analysis. You can start with the example notebooks in the `examples/` directory to understand how to use the provided functions and classes.

## Dependencies

You can install them using the following command:

```bash
pip install numpy pandas==2.0.0 tensorflow scikit-learn

==> aionx-1.0.5.tar.gz: aionx-1.0.5/README.md <==
# Machine Learning and Deep Learning for time series forecast

![MIT License](https://img.shields.io/badge/license-MIT-yellow.svg)
![Python](https://img.shields.io/badge/python-3.10%2B-blue)

This repository contains code and resources for Time Series forecast and analysis using Machine Learning and Deep Learning and is available under the MIT license. 

## Features

- Machine Learning and Deep Learning models for time series.
- Easy-to-use examples with [Scikit-Learn](https://scikit-learn.org/stable/), [Keras](https://keras.io/) and eventually [PyTorch](https://pytorch.org/).
- Only four dependencies:
    - [NumPy](https://numpy.org/) : The fundamental package for scientific computing in Python.
    - [Pandas](https://pandas.pydata.org/) : An open-source data analysis and manipulation library.
    - [TensorFlow](https://www.tensorflow.org/) : An open-source deep learning framework.
    - [Scikit-Learn](https://scikit-learn.org/stable/) : An open-source machine learning framework.
 
## Models

- Density Hemisphere Neural Network (DensityHNN):
    - Implements the model proposed by [Paper](linktopaper). DensityHNN is a deep Learning algorithm designed to produce Density forecasts on time-dependent data...

## Getting Started

1. Clone this repository:

    ```bash
    git clone https://github.com/TheAionxGit/aionx.git
    ```

2. Install the required dependencies:

    ```bash
    pip install -r requirements.txt
    ```

3. (TODO) explore the example notebooks in the `examples/` directory to get started.

## Usage

This repository provides a simple and flexible framework for time series analysis. You can start with the example notebooks in the `examples/` directory to understand how to use the provided functions and classes.

## Dependencies

You can install them using the following command:

```bash
pip install numpy pandas==2.0.0 tensorflow scikit-learn
